@@ -1,13 +1,13 @@
-# ----------------------------------------------------------
+# -------------------------------------------------------------
 # NDN Hydra Main
-# ----------------------------------------------------------
-# @Project: NDN Hydra
-# @Date:    2021-01-25
-# @Authors: Please check AUTHORS.rst
-# @Source-Code:   https://github.com/UCLA-IRL/ndn-hydra
-# @Documentation: https://ndn-hydra.readthedocs.io/
-# @Pip-Library:   https://pypi.org/project/ndn-hydra/
-# ----------------------------------------------------------
+# -------------------------------------------------------------
+#  @Project: NDN Hydra
+#  @Date:    2021-01-25
+#  @Authors: Please check AUTHORS.rst
+#  @Source-Code:   https://github.com/justincpresley/ndn-hydra
+#  @Documentation: https://ndn-hydra.readthedocs.io
+#  @Pip-Library:   https://pypi.org/project/ndn-hydra
+# -------------------------------------------------------------
 
 from argparse import ArgumentParser
 import asyncio as aio
@@ -49,41 +49,34 @@ def process_cmd_opts():
                 print("")
                 print("Thank you for using hydra.")
             sys.exit(0)
-    def process_prefix(input_string: str):
+    def process_name(input_string: str):
         if input_string[-1] == "/":
             input_string = input_string[:-1]
         if input_string[0] != "/":
             input_string = "/" + input_string
         return input_string
-    def process_others(input_string: str):
-        if input_string[-1] == "/":
-            input_string = input_string[:-1]
-        if input_string[0] == "/":
-            input_string = input_string[1:]
-        return input_string
     def parse_cmd_opts():
         # Command Line Parser
         parser = ArgumentParser(prog="ndn-hydra-repo",add_help=False,allow_abbrev=False)
-
         # Adding all Command Line Arguments
         parser.add_argument("-h","--help",action="store_true",dest="help",default=False,required=False)
         parser.add_argument("-v","--version",action="store_true",dest="version",default=False,required=False)
         parser.add_argument("-rp","--repoprefix",action="store",dest="repo_prefix",required=True)
         parser.add_argument("-n","--nodename",action="store",dest="node_name",required=True)
-
         # Interpret Informational Arguments
         interpret_version()
         interpret_help()
-
         # Getting all Arguments
         vars = parser.parse_args()
 
         # Process args
         args = {}
-        args["repo_prefix"] = process_prefix(vars.repo_prefix)
-        args["node_name"] = process_others(vars.node_name)
-        args["session_id"] = process_others(vars.node_name + str(gen_nonce()))
-        workpath = "{home}/.ndn/repo{repo_prefix}/{session_id}".format(home=os.path.expanduser("~"), repo_prefix=args["repo_prefix"], session_id=args["session_id"])
+        args["repo_prefix"] = process_name(vars.repo_prefix)
+        args["node_name"] = process_name(vars.node_name)
+        workpath = "{home}/.ndn/repo{repo_prefix}/{node_name}".format(
+            home=os.path.expanduser("~"),
+            repo_prefix=args["repo_prefix"],
+            node_name=args["node_name"])
         args["logging_path"] = "{workpath}/session.log".format(workpath=workpath)
         args["data_storage_path"] = "{workpath}/data.db".format(workpath=workpath)
         args["global_view_path"] = "{workpath}/global_view.db".format(workpath=workpath)
@@ -131,12 +124,13 @@ class HydraSessionThread(Thread):
         app = NDNApp()
 
         # databases
-        data_storage = SqliteStorage(self.config['data_storage_path'])
+        data_storage = SqliteStorage(self.config['data_storage_path']) # version
         global_view = GlobalView(self.config['global_view_path'])
+        svs_storage = SqliteStorage(self.config['svs_storage_path'])
         pb = PubSub(app)
 
         # main_loop (svs)
-        main_loop = MainLoop(app, self.config, global_view, data_storage)
+        main_loop = MainLoop(app, self.config, global_view, data_storage, svs_storage)
 
         # protocol (reads, commands & queries)
         read_handle = ReadHandle(app, data_storage, global_view, self.config)
@@ -152,7 +146,7 @@ class HydraSessionThread(Thread):
         # start listening
         try:
             app.run_forever(after_start=start_main_loop())
-        except FileNotFoundError:
+        except (FileNotFoundError, ConnectionRefusedError):
             print('Error: could not connect to NFD.')
             sys.exit()
 
@@ -160,13 +154,16 @@ def main() -> int:
     default_config = {
         'repo_prefix': None,
         'node_name': None,
-        'session_id': None,
         'data_storage_path': None,
         'global_view_path': None,
         'svs_storage_path': None,
         'logging_path': None,
-        #'svs_cache_others': True,
-		'period': 20
+        'loop_period': 5000,
+        'tracker_rate': 25000,
+        'heartbeat_rate': 20000,
+        'beats_to_renew': 3,
+        'beats_to_fail': 3,
+        'replication_degree': 2
     }
     cmd_args = process_cmd_opts()
     config = default_config.copy()
